@@ -20,9 +20,9 @@ def save_data(file_name, data, format):
 
 
 def _put_object(config, bucket, body, object_name):
-    s3_client = boto3.client('s3', aws_access_key_id=config['access_key_id'], aws_secret_access_key=config['secret_access_key'], region_name='us-east-1', endpoint_url= config['endpoint_url']) 
+    s3_client = boto3.client('s3', aws_access_key_id=config['cortx_authenticator']['access_key_id'], aws_secret_access_key=config['cortx_authenticator']['secret_access_key'], region_name='us-east-1', endpoint_url= config['endpoint_url']) 
     return s3_client.put_object(Body=body, Bucket=bucket, Key=object_name)
 
 def _get_object(config, bucket, object_name):
-    s3_client = boto3.client('s3', aws_access_key_id=config['access_key_id'], aws_secret_access_key=config['secret_access_key'], region_name='us-east-1', endpoint_url= config['endpoint_url'])
+    s3_client = boto3.client('s3', aws_access_key_id=config['cortx_authenticator']['access_key_id'], aws_secret_access_key=config['cortx_authenticator']['secret_access_key'], region_name='us-east-1', endpoint_url= config['endpoint_url'])
     return s3_client.get_object(Bucket=bucket, Key=object_name)
\ No newline at end of file
